@@ -1,4 +1,4 @@
 #!/bin/sh
 
 dbus-send --system --dest=org.bluez /org/bluez/hci0 org.bluez.Adapter.SetDiscoverableTimeout uint32:0
-dbus-send --system --dest=org.bluez /org/bluez/hci0 org.bluez.Adapter.SetMode string:connectable
+dbus-send --system --dest=org.bluez /org/bluez/hci0 org.bluez.Adapter.SetMode string:off
